"""main entry for e3smlab command-line interface"""

def main():
    from e3smlab import E3SMlab
    return E3SMlab().main()

if __name__ == "__main__":
    main()
